@@ -122,7 +122,8 @@ class Message:
             'chat_id': self.chat.id if 'chat_id' not in kwargs else kwargs.get('chat_id'),
             'disable_notification': False if 'disable_notification' not in kwargs else kwargs.get(
                 'disable_notification'),
-            'reply_to_message_id': self.message_id
+            'reply_to_message_id': self.message_id,
+
         }
         if reply_markup:
             data.update({'reply_markup': json.dumps(reply_markup.to_dict())})
@@ -130,6 +131,8 @@ class Message:
             data['caption'] = text
             data.pop('chat_id')
             return await self.send_photo(photo,**data)
+        if 'parse_mode' in kwargs:
+            data['parse_mode'] = kwargs.get('parse_mode')
         data['text'] = text
         rs = await self.bot.tg_request('sendMessage', True, **data)
         return rs.get('ok')
